# -*- coding: utf-8 -*-
import os
import sys
# 项目需要配置：

# mqtt配置
MQTT_IP = 'localhost'
MQTT_PORT = 1884

# 这个是后面加的,为了兼容以前代码,没配置默认user：admin pw：admin123
MQTT_USER = 'admin'
MQTT_PASSWORD = 'eHIGH2014'

# mqtt心跳
MQTT_KEEP_ALIVE = 60

# 打包方式json和pickle（默认json）
MQTT_PKG_TYPE = 'json'

# redis配置
REDIS_IP = 'localhost'
REDIS_PORT = 6379
REDIS_PASSWORD = 'eHIGH2014'
REDIS_DB = 0

# 默认数据库连接
DB_CONFIG = {
    'user': 'root',
    'password': 'eHIGH2014',
    'host': '127.0.0.1',
    'port': 3306,
    'dbname': 'test',
    'dbcharset': 'utf8',
    'use_unicode': True,
    'throw_alarm': True
}
# pymysql一次查询太多会卡死进程这里限制在20000
MAX_FIND_NUM = 20000

# 框架特有配置：

# 框架从数据库读取配置(False关闭,True开启)
CONFIG_FLAG = False

# 框架同步配置文件数据库
PW_DB_CONFIG = {
    'user': 'root',
    'password': 'eHIGH2014',
    'host': '127.0.0.1',
    'port': 3306,
    'dbname': 'python_worker_config',
    'dbcharset': 'utf8',
    'use_unicode': False,
    'throw_alarm': True,
    'tb_name': 'tb_config'
}

# 心跳服务：mqtt配置
USE_HEART = False
HEART_MQTT_IP = 'localhost'
HEART_MQTT_PORT = 1884
HEART_MQTT_USER = 'admin'
HEART_MQTT_PASSWORD = 'eHIGH2014'
HEART_TOPIC_DEL_DIR = '/home/ehigh/work/PythonWorker/Worker/'
HEART_TOPIC_FIRST = '/PythonWorker'
# 心跳发送时间
HEART_TIME = 1


# rpc默认超时时间
RPC_TIME_OUT = 5
RPC_REDIS_IP = 'localhost'
RPC_REDIS_PORT = 6379
RPC_REDIS_PASSWORD = 'eHIGH2014'
RPC_REDIS_DB = 7
RPC_REDIS_LOG_KEY = "RPC_ERROR_LOG"
RPC_REDIS_LOG_MAX = 50000

# 框架选择
SELECT_EPOLL = True

# 框架python使用
PYTHON_PATH = sys.executable

# 连接udp服务器将标准输出传递到udp服务器
udp_server = ('127.0.0.1', 50000)
# 查询status状态临时通信使用端口
STATUS_PORT = 31500

# consul ip,port
consul_ip = 'localhost'
consul_port = 8500
consul_token = 'f6786d6b-1901-87e5-78c3-074f90fc8fc6'

# 日志是否输出到终端
log_to_console = True

# CMqtt问题退出循环时间
break_time = 5

# 是否启用事件循环统计
flag_log_select = False



from pydantic import BaseModel

class MqttMessageMiddlewareClientConfig(BaseModel):
    host: str = '127.0.0.1'
    port: int= 1884
    password: str = 'eHIGH2014'
    username: str = 'admin'


class HttpClientConfig(BaseModel):
    host: str = "http://127.0.0.1"
    port: str = "80"


class RpcClientConfig(BaseModel):
    ip: str = "127.0.0.1"
    port: str = "1884"
    service_name: str = None





"""
录像服务sdk
"""

from . import main

message_middware_config = {
    "host": "127.0.0.1",
    "port": 1884,
    "password": "eHIGH2014",
    "username": "admin"
}
http_config = {
    "ip": "http://127.0.0.1",
    "port": "80"
}
rpc_config = {
    "ip": "127.0.0.1",
    "port": 10000,
    "service_name": "test"
}
cm = main.CallMethod(
    mmc=main.MqttMessageMiddlewareClientImpl(),
    hc=main.PyHttpClientImpl(),
    rc=main.PwRpcClientImpl(),
    mmcc=main.MqttMessageMiddlewareClientConfig(**message_middware_config),
    hcc=main.HttpClientConfig(**http_config),
    rcc=main.RpcClientConfig(**rpc_config)
)


def login(username: str, password: str, http_api_version: str):
    """
    登录sdk接口
    :param username: 用户名
    :param password:    密码
    :param http_api_version: 版本号
    :return:
    """
    return cm.message_http(
        method="post",
        data={
            "username": username,
            "password": password,
            "http_api_version": http_api_version
        },
        uri="/EHCommon/admin/user/login"
    )


def query_start(data):
    cm.message_middleware_publish(r"gs/record/start/req", data=data)


# @staticmethod
# def query_check(data):
#     cm.message_middleware_publish("gs/record/check/req", data=data)

# @staticmethod
# def check(param=None):
#     return cm.rpc_client.call(
#         module="gs_camera_record",
#         ip="127.0.0.1",
#         port="12001",
#         service_name="DemoRPCServer",
#         func="start",
#         param=param)


def start(param=None):
    return cm.rpc_client.call(
        module="gs_camera_record",
        base_config=cm.rpc_client_config,
        func="start",
        param=param)


def test_subscribe(callback):
    cm.message_middleware_subscribe(topic=r"gs/record/start/res", callback=callback)



import sys
from . import camera

data = {
    "things_id": 3, "card_id": 100001, "position": "3.0,4.0,0",
    "metadata": {"alarm_record_id": 1, "process_node_id": "bd0024a8-b503-484d-b9eb-fdea9a17761c"}
}

def call(*args):
    print(*args)
    print(args[2].topic, args[2].payload)
    sys.exit(1)

# sdk.SdkInterface.login(
#     username='admin', password='c93ccd78b2076528346216b3b2f701e6', http_api_version='4.7.1'
# )

# mqtt
# sdk.SdkInterface.query_start(data)
# sdk.SdkInterface.test_subscribe(call)

# rpc
res = camera.start(data)
print(res)



# -*- coding: utf-8 -*-
from httplib2 import Http
import time
from .consul_client import get_service

import json

import pickle


class ComputeProxy(object):
    SUBMITTASK_NONBLOCKED = "submitTaskNonBlocked"

    SUBMITTASK_BLOCKED = "submitTaskBlocked"

    GET_TASK_RESULT = "getTaskResult"

    task_result = {}

    def __init__(self, module=None, ip="localhost", port="8888", type="json", time_out=30, service_name=None):

        # 通过consul方式获取信息
        if service_name:
            service_ip, service_port = get_service(service_name)
            if service_ip and service_port:
                ip = service_ip
                port = service_port
        # print(ip,port)
        self.__module = module
        self.__ip = ip
        self.__port = str(port)
        self._type = type
        self._time_out = time_out

    def setTaskModule(self, module):
        self.__module = module

    def __getattr__(self, name):

        def submitTaskBlocked(*args):
            url = "http://" + self.__ip + ":" + self.__port + "/" + self.SUBMITTASK_BLOCKED
            if self._type == 'bin':
                return self.__buildSubmitRpcPackage(url, name, *args)
            else:
                return self.__buildSubmitRpcPackage(url, name, args)

        return submitTaskBlocked

    def submitNonTaskBlocked(self, item):
        self.__checkTaskArrayFormation(item)
        url = "http://" + self.__ip + ":" + self.__port + "/" + self.SUBMITTASK_NONBLOCKED
        return self.__buildSubmitRpcPackage(url, None, item)

    def __buildSubmitRpcPackage(self, url, method, paras):

        if (self.__module is None):
            raise AttributeError

        post_data = {}

        try:
            http = Http(timeout=self._time_out)
            if (method is not None):
                post_data['method'] = method

            post_data['params'] = paras
            post_data['module'] = self.__module

            if self._type == 'json':

                post_http_data = json.dumps(post_data)
                hearder, content = http.request(url, method="POST",
                                                headers={"Content-Type": "application/json"},
                                                body=post_http_data)
            elif self._type == 'bin':
                hearder, content = http.request(url, method="POST",
                                                headers={"content-type": "application/octet-stream",
                                                         "rpc-class": post_data['module'],
                                                         "rpc-method": post_data['method']},
                                                body=post_data['params'])

            elif self._type == 'pickle':
                post_http_data = pickle.dumps(post_data, 2)
                hearder, content = http.request(url, method="POST",
                                                headers={"Content-Type": "application/octet-stream"},
                                                body=post_http_data)

        except Exception as e:
            log_info = {}
            log_info['ip'] = self.__ip
            log_info['port'] = self.__port
            log_info['type'] = self._type
            log_info['time_out'] = self._time_out
            log_info['time'] = time.time()
            log_info['method'] = method
            log_info['params'] = paras
            log_info['module'] = self.__module
            log_info['err_msg'] = str(e)

            if log_info['err_msg'] == 'timed out':
                raise Exception("连接超时")
            else:
                raise Exception("无法建立到服务器的连接，请检查服务器是否启动，地址是否正确,错误信息：" + str(e))

        if (hearder["status"] == "500"):
            raise Exception("服务器内部错误")

        if (hearder["status"] == "404"):
            raise Exception("错误的请求路径")

        if (hearder["status"] != "200"):
            raise Exception("请求没能被正确处理,HTTP错误码 " + hearder["status"])

        try:
            content = json.loads(content)
        except Exception:
            raise TypeError("返回结果格式错误，无法转换为json对象")

        if (content["result"] == "error"):
            if (content["code"] == 32601):
                raise Exception("任务过程出现错误")
            elif (content["code"] == 32602):
                raise ValueError("数据格式错误")
            elif (content["code"] == 32000):
                raise Exception("服务器内部出现错误")
            else:
                raise Exception("任务出现未知错误")

        return content['data']

    def __buildGetTaskResultPackage(self, task_ids, url):

        post_data = []
        for i in task_ids:
            task_id = {}
            task_id['task_id'] = i
            post_data.append(task_id)
        post_json_data = json.dumps(post_data)
        http = Http()

        try:
            hearder, content = http.request(url, "POST", post_json_data)
        except Exception:
            raise Exception("无法建立到服务器的连接，请检查服务器是否启动，地址是否正确")

        if (hearder["status"] == "500"):
            raise Exception("服务器内部错误")

        if (hearder["status"] == "404"):
            raise Exception("错误的请求路径")

        if (hearder["status"] != "200"):
            raise Exception("请求没能被正确处理,HTTP错误码 " + hearder["status"])

        try:
            content = json.loads(content)
        except Exception:
            raise TypeError("返回结果格式错误，无法转换为json对象")

        if (content["result"] == "error"):
            if (content["code"] == 32601):
                raise Exception("任务过程出现错误")
            elif (content["code"] == 32602):
                raise ValueError("数据格式错误")
            elif (content["code"] == 32000):
                raise Exception("服务器内部出现错误")
            else:
                raise Exception("任务出现未知错误")

        return content['data']

    def isTaskNonBlockedResultReady(self, task_id):

        if (len(task_id) < 1):
            raise ValueError("数据格式错误，格式为[ task_id,task_id.... ]")

        url = "http://" + self.__ip + ":" + self.__port + "/" + self.GET_TASK_RESULT
        ret = self.__buildGetTaskResultPackage(task_id, url)

        return_data = []
        for i in ret:
            if i['result'] == 'ready':
                return_data.append(i['data'])
            else:
                return_data.append(False)
        return return_data

    def __checkTaskArrayFormation(self, value):
        if len(value) < 1:
            raise ValueError("提交异步任务的的数据格式错误，格式为[['job1',[args]],['job2',[args]]....]")
        for i in value:
            if len(i) != 2:
                raise ValueError("提交异步任务的的数据格式错误,格式为[['job1',[args]],['job2',[args]]....]")

    def getTaskNonBlockedResult(self, task_id):
        if self.task_result[task_id] is not None:
            result = self.task_result[task_id]
            del self.task_result[task_id]
            return result
        else:
            raise AttributeError()



# -*- coding: utf-8 -*-
from abc import ABCMeta, abstractmethod
import paho.mqtt.client as mqtt
import json
import requests

from .ComputeProxy import ComputeProxy
from .config import MqttMessageMiddlewareClientConfig
from .config import HttpClientConfig
from  .config import RpcClientConfig

class MessageMiddlewareClient(metaclass=ABCMeta):
    """
    消息中间件客户端
    """

    @abstractmethod
    def publish(self, topic, data, base_config: MqttMessageMiddlewareClientConfig):
        pass


class MqttMessageMiddlewareClientImpl(MessageMiddlewareClient):
    """
    MQTT客户端
    """
    def publish(self, topic, data, base_config: MqttMessageMiddlewareClientConfig):
        client = mqtt.Client()
        client.username_pw_set(base_config.username, base_config.password)
        client.connect(base_config.host, base_config.port)
        if isinstance(data, str):
            data = data.encode("utf-8")
        elif isinstance(data, (list, dict, tuple, set)):
            data = json.dumps(data)
        else:
            raise TypeError("数据类型错误")
        client.publish(topic, data)

class HttpClient(metaclass=ABCMeta):
    """
    http客户端
    """
    @abstractmethod
    def call(self, base_config:HttpClientConfig, uri: str, data: json, method: str, headers=None):
        pass


class PyHttpClientImpl(HttpClient):
    """
    使用python包调用http接口
    """
    def call(self, base_config: HttpClientConfig, uri: str, data: json, method: str, headers=None):
        call_address = base_config.host + ":" + base_config.port + "/" + uri

        response = requests.request(method=method, url=call_address, json=data, headers=headers)
        return response.json()


class RpcClient(metaclass=ABCMeta):
    @abstractmethod
    def call(self, module=None, base_config: RpcClientConfig=None, func=None, param=None):
        pass


class PwRpcClientImpl(RpcClient):
    def call(self, module=None, base_config: RpcClientConfig=None, func=None, param=None):
        client = ComputeProxy(module=module,
                              ip=base_config.ip,
                              port=base_config.port,
                              service_name=base_config.service_name
                              )
        if hasattr(client, func):
            if isinstance(param, tuple):
                return getattr(client, func)(*param)
            elif isinstance(param, dict):
                return getattr(client, func)(param)
        raise Exception


class CallMethod:
    def __init__(self, mmc: MessageMiddlewareClient = None, hc: HttpClient = None, rc: RpcClient = None,
                 mmcc: MqttMessageMiddlewareClientConfig = None, hcc: HttpClientConfig = None,
                 rcc: RpcClientConfig =None
                 ):
        """
        初始化
        :param mmc: 消息中间件客户端
        :param hc: http客户端
        :param rc: rpc客户端
        :param mmcc: 消息中间件客户端配置如地址，端口等配置
        """
        self._middleware_client = mmc
        self._http_client = hc
        self._rc = rc
        self._middleware_client_config = mmcc
        self._http_client_config = hcc
        self._rpc_client_config = rcc

    @property
    def http_client_config(self):
        """
        获取http基础配置
        :return:
        """
        return self._http_client_config

    @http_client_config.setter
    def http_client_config(self, hcc: HttpClientConfig):
        """
        设置http基础配置
        :param hcc:
        :return:
        """
        self._http_client_config = hcc

    @property
    def message_middleware_client(self):
        """
        返回消息中间件客户端
        :return:
        """
        return self._middleware_client

    @message_middleware_client.setter
    def message_middleware_client(self, mmc: MessageMiddlewareClient):
        """
        设置消息中间件客户端
        :param mmc:
        :return:
        """
        self._middleware_client = mmc

    @property
    def http_client(self):
        """
        返回http客户端
        :return:
        """
        return self._http_client

    @http_client.setter
    def http_client(self, hc: HttpClient):
        """
        设置http客户端
        :param hc:
        :return:
        """
        self._http_client = hc

    @property
    def rpc_client(self):
        """
        获取rpc客户端
        :return:
        """
        return self._rc

    @rpc_client.setter
    def rpc_client(self, hc: RpcClient):
        """
        设置rpc客户端
        :param hc:
        :return:
        """
        self._rc = hc

    @property
    def message_middleware_client_config(self):
        """
        返回消息中间件配置
        :return:
        """
        return self._middleware_client_config

    @message_middleware_client_config.setter
    def message_middleware_client_config(self, mmcc: MqttMessageMiddlewareClientConfig):
        """
        动态设置消息中间件配置
        :param mmcc:
        :return:
        """
        self._middleware_client_config = mmcc

    @property
    def rpc_client_config(self):
        """
        获取rpc客户端配置
        :return:
        """
        return self._rpc_client_config

    @rpc_client_config.setter
    def rpc_client_config(self, rcc:RpcClientConfig):
        """
        设置rpc客户端配置
        :param rcc:
        :return:
        """
        self._rpc_client_config = rcc

    def message_middleware_publish(self, topic, data):
        """
        消息中间件发布主题
        :param topic:
        :param data:
        :return:
        """
        if not self._middleware_client:
            raise Exception("消息中间件客户端未初始化")

        if not hasattr(self._middleware_client, "publish"):
            raise Exception("消息中间件客户端未实现publish方法")
        self._middleware_client.publish(topic=topic, data=data, base_config=self._middleware_client_config)

    def message_http(self, method, data, uri, headers=None):
        """
        供sdk接口调用其他服务http接口
        :param method:
        :param data:
        :param url:
        :param headers:
        :return:
        """
        if not self._http_client:
            raise Exception("http客户端未初始化")

        if not hasattr(self._http_client, "call"):
            raise Exception("http客户端未实现call方法")

        return self._http_client.call(base_config=self._http_client_config, uri=uri, data=data, method=method, headers=headers)

    def message_rpc(self, module, func, param):
        """
        供sdk接口调用其他服务rpc接口
        :param module:
        :param ip:
        :param port:
        :param service_name:
        :param func:
        :param param:
        :return:
        """
        if not self._rc:
            raise Exception("rpc客户端未初始化")

        if not hasattr(self._rc, "call"):
            raise Exception("rpc客户端未实现call方法")

        return self._rc.call(module=module, base_config=self._rpc_client_config, func=func, param=param)

# message_middware_config = {
#     "host": "127.0.0.1",
#     "port": 1884,
#     "password": "eHIGH2014",
#     "username": "admin"
# }
# http_config = {
#     "ip": "http://127.0.0.1",
#     "port": "80"
# }
# rpc_config = {
#     "ip": "127.0.0.1",
#     "port": 10000,
#     "service_name": "test"
# }
# cm = CallMethod(
#     mmc=MqttMessageMiddlewareClientImpl(),
#     hc=PyHttpClientImpl(),
#     rc=PwRpcClientImpl(),
#     mmcc=MqttMessageMiddlewareClientConfig(**message_middware_config),
#     hcc= HttpClientConfig(**http_config),
#     rcc= RpcClientConfig(**rpc_config)
# )



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="gs_sdk",
    version="2.0.0",
    author="duqiang",
    author_email="1427327705@qq.com",
    description="sdk调用",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://forthink.xin:8889/dq/sdk.git",
    packages=setuptools.find_packages(),
    classifiers=[],
    python_requires=">=3.9",
    install_requires=[
        'python-consul == 1.1.0',
        'paho-mqtt == 1.6.1',
        'pydantic == 1.8.2'
    ],
)


import sys
import uuid
from pydantic import BaseModel, Field
sys.path.append("../..")
from Core.HGHttpServer.HttpServer import HttpServer
from Core.HGPythonWorker import HGPythonWorker
from Core.MqttClient import MQTT

RPC_PORT_MAIN = 10000
TOPIC_QUERY = r"gs/record/start/req"
TOPIC_REPLY = r"gs/record/start/res"

some_things = []


def get_uuid():
    return uuid.uuid1().hex


class Event(BaseModel):
    '''
    {"things_id": 1, "card_id": 100, "position": "1.0,2.5,0",
    "metadata": {"alarm_record_id": 1, "process_node_id": "bd0024a8-b503-484d-b9eb-fdea9a17761c}
    '''
    things_id: int = Field(..., description='事物id')
    card_id: int = Field(..., description='定位卡id')
    position: str = Field(..., description='位置以逗号分隔')
    metadata: dict = Field(..., description='节点信息')
    task_uuid: str = Field(default_factory=get_uuid, description='任务uuid用于查询文件')
    camera_id: int = Field(0, description='返回摄像机id，空为不存在')
    status: int = Field(0, description='返回录像状态，负值为失败')


def start(data: Event, _topic) -> Event:
    global some_things
    data = Event(**data)
    if data.metadata in some_things:
        return None

    print('start', data)
    some_things.append(data.metadata)
    data.camera_id = 1
    data.status = 1
    data = data.dict()
    MQTT.publish(TOPIC_REPLY, data)
    print('reply', data)
    return data


MQTT.addTopicHandler(TOPIC_QUERY, start)


class HttpAPIServer(object):
    def start(self, data):
        try:
            return start(data, False)
        except Exception as err:
            return None


server = HttpServer(RPC_PORT_MAIN)
testServer = HttpAPIServer()
server.addClass({"gs_camera_record": testServer})
# register_service(Config.RPC_NAME_MAIN, Config.RPC_PORT_MAIN)
HGPythonWorker.run([server], mq=MQTT)



# -*- coding: utf-8 -*-
import consul
import socket

from . import PWConfig


class HGConsul(object):
    ''' 注册相同的服务名不会报错而是会覆盖！查询相同的服务永远只会取第一个，不能用于分布式节点！
    '''
    def __init__(self, host, port):
        """
        初始化，连接consul服务器
        :param host: 服务器ip地址
        :param port: 服务器端口
        """
        self._consul = consul.Consul(host, port)

    def register_service(self, name, host=None, port=8500, tags=None) -> bool:
        """
        向agent注册服务,服务名本身不用唯一,服务id重复了不会报错而是会覆盖
        :param name:服务名称,因为该字段这里被用作id,所以在一台服务器上必须是唯一值
        :param host:服务的ip地址
        :param port:服务的端口
        :param tags:
        :return: bool
        """
        tags = tags or []
        if host is None:
            host = self.get_host_ip()
        # 注册服务
        return self._consul.agent.service.register(
            name=name,
            service_id=name,
            address=host,
            port=port,
            tags=tags,
            token=PWConfig.consul_token,
            # 健康检查ip端口，检查时间：5,超时时间：30，注销时间：30s
            check=consul.Check().tcp(host, port, "5s", "30s", "30s"))

    def delete_register(self, name) -> bool:
        """
        从agent删除服务
        :param name: 服务名称实际是服务id
        :return: bool
        """
        return self._consul.agent.service.deregister(name)

    def register_discovery(self) -> list:
        """
        发现所有服务，原始返回值是以服务名为键，Tags为值的词典，此处返回服务名列表
        库返回值中的数字是什么意思？数据一定在[1]吗？
        :return:
        """
        return self._consul.catalog.services()[1].keys()

    def get_service(self, name):
        """
        根据服务id/服务名获得服务的ip地址和端口.
        :param name: 服务名称
        :return:
        """
        service = self._consul.catalog.service(name, token=PWConfig.consul_token)
        if not (service and service[1]):            
            return None, None
        '''
        (index, [
                    {
                        "Node": "foobar",
                        "ServiceAddress": "10.1.10.12",
                        "ServiceID": "redis",
                        "ServiceName": "redis",
                        "ServiceTags": null,
                        "ServicePort": 8000
                    }
                ])
        同一个name可能存在多个服务，默认只取第一个
        agent的查询取ID，catalog的查询取名字，因此这里可能存在多个服务（如果有其他服务节点）
        分布式会存在问题！
        '''
        return service[1][0]['ServiceAddress'], service[1][0]['ServicePort']

    @staticmethod
    def get_host_ip():
        """
        查询本机ip地址
        :return: ip
        """
        try:
            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
            s.connect(('8.8.8.8', 80))
            ip = s.getsockname()[0]
        finally:
            s.close()
        return ip


def register_service(service_name, port, ip=None):
    """
    服务注册
    :param service_name: 服务名称,因为该字段也被用作id,所以在一台服务器上具有唯一性
    :param port: 服务的端口
    :param ip: 服务的ip地址
    :return:
    """
    try:
        if service_name:
            consul_client = HGConsul(PWConfig.consul_ip, PWConfig.consul_port)
            consul_client.register_service(service_name, host=ip, port=port)
        return True
    except:        
        return False


def get_service(service_name):
    """
    获得服务的ip地址和端口.
    :param service_name: 服务名称
    :return:
    """
    try:
        consul_client = HGConsul(PWConfig.consul_ip, PWConfig.consul_port)
        return consul_client.get_service(service_name)
    except:
        return None, None


if __name__ == '__main__':
    # consul服务器的ip
    host = "192.168.13.76"  # host = "http://forthink.xin/"
    # consul服务器对外的端口 不能使用字符串格式！
    port = 8500
    consul_client = HGConsul(host, port)

    name = 'apple'
    res = consul_client.register_service(name, host='192.168.1.23', port=1884, tags=['frute'])
    print('register', res)

    host2 = "192.168.0.101"
    consul_client2 = HGConsul(host2, port)
    res = consul_client2.register_service(name, host='192.168.1.22', port=1884, tags=['frute'])
    print('register2', res)

    res = consul_client.register_discovery()
    print('getall', res)
    res = consul_client.get_service(name)
    print('find', res)

    check = consul.Check().tcp(host, port, "5s", "30s", "30s")
    print('check', check)

    res = consul_client.delete_register(name)
    print('deregister', res)
    res = consul_client2.delete_register(name)
    print('deregister2', res)